{% load i18n bootstrap %}

<form method="post">
    <div class="form-group">
        {% csrf_token %}
        {{ form.email | bootstrap }}
        {% if instance.fullname_show %}
            {{ form.first_name | bootstrap }}
            {{ form.last_name | bootstrap }}
        {% endif %}
        <input class="btn btn-default" type="submit" name="submit" value={% trans "Subscribe" %} />
    </div>
</form>
