# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-09-20 09:54
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('cms', '0016_auto_20160608_1535'),
    ]

    operations = [
        migrations.CreateModel(
            name='MenuPluginModel',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='cms_qe_menu_menupluginmodel', serialize=False, to='cms.CMSPlugin')),
                ('orientation', models.IntegerField(choices=[(1, 'Horizontal'), (2, 'Vertical')], default=1)),
                ('start_page', models.CharField(blank=True, help_text='ID of page in advanced settings.', max_length=50)),
                ('end_level', models.IntegerField(default=2, help_text='\n            Specify at which level the navigation should stop.\n\n            Keep in mind that Bootstrap by default does not support dropdown submenu.\n            Any deep dropdown menu is not very well accessible from mobile devices.\n        ', verbose_name='End level')),
                ('submenu_in_inactive_item', models.BooleanField(default=True, verbose_name='Submenu for inactive items')),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
    ]
