{% load menu_tags cache %}

<ul>
    {% for child in children %}
        <li>
            <a href="{{ child.get_absolute_url }}">{{ child.get_menu_title }}</a>
            <ul>
                {% show_menu from_level to_level extra_inactive extra_active template "" "" child %}
            </ul>
        </li>
    {% endfor %}
</ul>
