{% load i18n %}

<h1>{{ title|default:_("Register a new account") }}</h1>
<form method="post" action="{% url 'register' %}">
    {% csrf_token %}
    <table>
        {{ form.as_table }}
        <tr>
            <td></td>
            <td>
                <input type="submit" value="{{ submit|default:_("Register") }}" />
                <br />
                <a href="{% url 'login' %}">{% trans "Log in instead?" %}</a>
            </td>
        </tr>
    </table>
</form>
