{% extends CMS_TEMPLATE %}
{% load i18n %}

{% block title %}{% trans "Logged out" %}{% endblock %}

{% block content %}
    <p>{% trans "Thanks for spending some quality time with the Web site today." %}</p>
    <p><a href="{% url 'login' %}">{% trans 'Log in again' %}</a></p>
{% endblock %}
