{% load i18n %}

<p>
    {% url 'login' as login_url %}
    {% url 'logout' as logout_url %}
    {% blocktrans with username=user.username %}
        You are already logged in as <strong>{{ username }}</strong>.
        Do you want to log in as <a href="{{ logout_url }}?next={{ login_url }}">different user</a>?
    {% endblocktrans %}
</p>
