{% extends CMS_TEMPLATE %}
{% load i18n %}

{% block title %}{% trans "Register a new account" %}{% endblock %}

{% block content %}
    {% include "cms_qe/auth/register_plugin.html" %}
{% endblock %}
