{% load i18n %}

<div class="container">
    <h3>{{ instance.title }}</h3>
    {% if not form.saved %}
        {% include 'cms_qe/newsletter/form.html' %}
    {% else %}
        {% include 'cms_qe/newsletter/submitted.html' %}
    {% endif %}
</div>
