
{% if instance.paging_show %}
    <ul class="pagination">
        <li {% if not items.has_previous %}class="disabled"{% endif %}>
            <a href="{% if items.has_previous %}?{{ page_param_name }}={{ items.previous_page_number }}{% else %}#{% endif %}" aria-label="Previous">
                <span aria-hidden="true">&laquo;</span>
            </a>
        </li>

        {% for page in items.paginator.page_range %}
            <li {% if items.number == page %}class="active"{% endif %}><a href="?{{ page_param_name }}={{ page }}">{{ page }}</a></li>
        {% endfor %}

        <li {% if not items.has_next %}class="disabled"{% endif %}>
            <a href="{% if items.has_next %}?{{ page_param_name }}={{ items.next_page_number }}{% else %}#{% endif %}" aria-label="Next">
                <span aria-hidden="true">&raquo;</span>
            </a>
        </li>
    </ul>
{% endif %}
