# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-09-20 09:54
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import jsonfield.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('cms', '0016_auto_20160608_1535'),
    ]

    operations = [
        migrations.CreateModel(
            name='TablePluginModel',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='cms_qe_table_tablepluginmodel', serialize=False, to='cms.CMSPlugin')),
                ('table', models.CharField(max_length=100, verbose_name='Table to show')),
                ('columns', jsonfield.fields.JSONField(default=dict, verbose_name='Columns to show')),
                ('paging_show', models.BooleanField(default=True, verbose_name='Show paging')),
                ('paging_per_page', models.IntegerField(default=20, verbose_name='How many items per page when paging')),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
    ]
