{% load cache %}

<ul class="nav {% if instance.is_horizontal %} navbar-nav {% endif %}{% if instance.is_vertical %} nav-stacked {% endif %}">
    {% include "cms_qe/menu/menu_items.html" with children=children only %}
</ul>
<div class="clearfix"></div>
