{% load i18n bootstrap %}

<div class="modal-dialog">
    <div class="modal-content">
        <div class="modal-header">
            <h1 class="modal-title">{{ title|default:_("Register a new account") }}</h1>
        </div>
        <div class="modal-body">
            <form method="post" action="{% url 'register' %}">
                {% csrf_token %}
                {{ form|bootstrap }}
                <input type="submit" class="form-control btn btn-primary" value="{{ submit|default:_("Register") }}" />
                <p><a href="{% url 'login' %}">{% trans "Log in instead?" %}</a></p>
            </form>
        </div>
    </div>
</div>
