{% load i18n %}

{% if request.user.is_authenticated %}
    {{ request.user.get_full_name }} | <a href="{% url 'logout' %}">{% trans "Logout" %}</a>
{% else %}
    <a href="{% url 'login' %}">{% trans "Login" %}</a>
{% endif %}
