
<ol class="breadcrumb">
    {% for ance in ancestors %}
        <li {% if ance.selected %}class="active"{% endif %}><a href="{{ ance.get_absolute_url }}">{{ ance.get_menu_title }}</a></li>
    {% endfor %}
</ol>
