{% extends CMS_TEMPLATE %}
{% load i18n bootstrap %}

{% block title %}{{ title }}{% endblock %}

{% block content %}
<div class="row">
<div class="col-md-6 col-md-offset-3 col-sm-8 col-sm-offset-2">
    <p>{% trans "Forgotten your password? Enter your email address below, and we'll email instructions for setting a new one." %}</p>
    <form method="post">
        {% csrf_token %}
        {{ form|bootstrap }}
        <input type="submit" class="form-control btn btn-primary" value="{% trans "Reset my password" %}" />
    </form>
</div>
</div>
{% endblock %}
